/* ***************************************************************************
   *  Kindermann                                 WPK Produktentwicklung      *
   *                                             Schuljahr: 2014/15          *
   *                                                                         *
   *                            TETRIS VGA 20MHz                             *
   *                            fr das USB-Board                            *
   *                                                                         *
   ***************************************************************************/


#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>
#include <avr/eeprom.h>
#ifndef F_CPU
#define F_CPU (20.000000)
#endif
#include <util/delay.h>
#include "AVGA/avga.h"
#include "AVGA/core/video.h"
#include "AVGA/core/driver.h"
#include "AVGA/utils/misc.h"
#include "graphics/tetris-map.h"
#include "graphics/tetris-tileset.h"
#include "sounds/music.h"
#include "tetris.h"

#define free_space(x,y) ( ((mode0_get_block(DIV8(x), DIV10(y)) & 0xf0) == 0x20) || \
	mode0_is_rammap(mode0_get_block(DIV8(x), DIV10(y))))

unsigned char stop = 0;
const char tetris_board[] PROGMEM =  MAP;

//memory for the driver.
unsigned char screen[DRIVER_SCREEN_SIZE];
const unsigned char pgmmap[] PROGMEM = GRAPHICS;
unsigned char rammap[DRIVER_RAMMAP_SIZE];


extern unsigned char sound_timer;

int main(void)
{
	uint8_t i;
	uint8_t lives, level, credits;
	uint16_t score;

    sound_init();

    driver_mmap(screen, pgmmap, rammap);

    video_init(VGA_NEU);

    enable();

	key_init();

	sound_init();

    driver_clear();

	// Display Game board
	memcpy_P(&mode0_get_block(0,1), tetris_board, 22 * MODE0_COLUMNS);

  	while(!key_read(KEY_ANY));

	BOX_start_game();

	// Game Loop

    while(1)
      {
      // Read keys
	  switch(key_read(KEY_DIR))
	    {
	    while (stop);

	    case KEY_RIGHT:
		  {
          BOX_rt();
		  delay(5);
		  }
        break;
	    case KEY_LEFT:
		  {
          BOX_lt();
		  delay(5);
		  }
	    break;
	    case KEY_UP:
	      {
          BOX_rotate(1);
		  delay(5);
		  }
	    break;
	    case KEY_DOWN:
		  {
          BOX_dn();
          delay(5);
		  }
	    break;
	    }
      if (sound_timer == 0) {sound_play(tetris); }
	  }
}


